@@ -70,6 +70,7 @@ const char *connman_device_get_control(struct connman_device *device);
 
 void connman_device_set_ident(struct connman_device *device,
 						const char *ident);
+const char *connman_device_get_ident(struct connman_device *device);
 
 void connman_device_set_mode(struct connman_device *device,
 					enum connman_device_mode mode);
@@ -79,7 +80,6 @@ int connman_device_set_powered(struct connman_device *device,
 						connman_bool_t powered);
 int connman_device_set_scanning(struct connman_device *device,
 						connman_bool_t scanning);
-void connman_device_cleanup_scanning(struct connman_device *device);
 
 int connman_device_set_disconnected(struct connman_device *device,
 						connman_bool_t disconnected);
