@@ -315,10 +315,6 @@ static DBusMessage *get_properties(DBusConnection *conn,
 
 	DBG("conn %p", conn);
 
-	if (__connman_security_check_privilege(msg,
-					CONNMAN_SECURITY_PRIVILEGE_PUBLIC) < 0)
-		return __connman_error_permission_denied(msg);
-
 	reply = dbus_message_new_method_return(msg);
 	if (reply == NULL)
 		return NULL;
@@ -412,10 +408,6 @@ static DBusMessage *set_property(DBusConnection *conn,
 	dbus_message_iter_next(&iter);
 	dbus_message_iter_recurse(&iter, &value);
 
-	if (__connman_security_check_privilege(msg,
-					CONNMAN_SECURITY_PRIVILEGE_MODIFY) < 0)
-		return __connman_error_permission_denied(msg);
-
 	type = dbus_message_iter_get_arg_type(&value);
 
 	if (g_str_equal(name, "Powered") == TRUE) {
@@ -958,7 +950,7 @@ void connman_device_set_ident(struct connman_device *device,
 	device->ident = g_strdup(ident);
 }
 
-const char *__connman_device_get_ident(struct connman_device *device)
+const char *connman_device_get_ident(struct connman_device *device)
 {
 	return device->ident;
 }
