@@ -32,15 +32,11 @@ static DBusMessage *get_properties(DBusConnection *conn,
 {
 	DBusMessage *reply;
 	DBusMessageIter array, dict;
-	connman_bool_t offlinemode;
+	connman_bool_t offlinemode, tethering;
 	const char *str;
 
 	DBG("conn %p", conn);
 
-	if (__connman_security_check_privilege(msg,
-					CONNMAN_SECURITY_PRIVILEGE_PUBLIC) < 0)
-		return __connman_error_permission_denied(msg);
-
 	reply = dbus_message_new_method_return(msg);
 	if (reply == NULL)
 		return NULL;
@@ -58,8 +54,6 @@ static DBusMessage *get_properties(DBusConnection *conn,
 			DBUS_TYPE_OBJECT_PATH, __connman_profile_list, NULL);
 	connman_dbus_dict_append_array(&dict, "Services",
 			DBUS_TYPE_OBJECT_PATH, __connman_service_list, NULL);
-	connman_dbus_dict_append_array(&dict, "Providers",
-			DBUS_TYPE_OBJECT_PATH, __connman_provider_list, NULL);
 	connman_dbus_dict_append_array(&dict, "Technologies",
 			DBUS_TYPE_OBJECT_PATH, __connman_technology_list, NULL);
 
@@ -71,6 +65,10 @@ static DBusMessage *get_properties(DBusConnection *conn,
 	connman_dbus_dict_append_basic(&dict, "OfflineMode",
 					DBUS_TYPE_BOOLEAN, &offlinemode);
 
+	tethering = __connman_tethering_get_status();
+	connman_dbus_dict_append_basic(&dict, "Tethering",
+					DBUS_TYPE_BOOLEAN, &tethering);
+
 	connman_dbus_dict_append_array(&dict, "AvailableTechnologies",
 		DBUS_TYPE_STRING, __connman_notifier_list_registered, NULL);
 	connman_dbus_dict_append_array(&dict, "EnabledTechnologies",
@@ -109,10 +107,6 @@ static DBusMessage *set_property(DBusConnection *conn,
 	dbus_message_iter_next(&iter);
 	dbus_message_iter_recurse(&iter, &value);
 
-	if (__connman_security_check_privilege(msg,
-					CONNMAN_SECURITY_PRIVILEGE_MODIFY) < 0)
-		return __connman_error_permission_denied(msg);
-
 	type = dbus_message_iter_get_arg_type(&value);
 
 	if (g_str_equal(name, "OfflineMode") == TRUE) {
@@ -123,9 +117,23 @@ static DBusMessage *set_property(DBusConnection *conn,
 
 		dbus_message_iter_get_basic(&value, &offlinemode);
 
-		__connman_profile_set_offlinemode(offlinemode);
+		__connman_profile_set_offlinemode(offlinemode, TRUE);
 
 		__connman_profile_save_default();
+	} else if (g_str_equal(name, "Tethering") == TRUE) {
+		connman_bool_t tethering;
+
+		if (type != DBUS_TYPE_BOOLEAN)
+			return __connman_error_invalid_arguments(msg);
+
+		dbus_message_iter_get_basic(&value, &tethering);
+
+		if (__connman_tethering_set_status(tethering) < 0)
+			return __connman_error_invalid_arguments(msg);
+
+		connman_dbus_property_changed_basic(CONNMAN_MANAGER_PATH,
+					CONNMAN_MANAGER_INTERFACE, "Tethering",
+						DBUS_TYPE_BOOLEAN, &tethering);
 	} else if (g_str_equal(name, "ActiveProfile") == TRUE) {
 		const char *str;
 
@@ -145,10 +153,6 @@ static DBusMessage *get_state(DBusConnection *conn,
 
 	DBG("conn %p", conn);
 
-	if (__connman_security_check_privilege(msg,
-					CONNMAN_SECURITY_PRIVILEGE_PUBLIC) < 0)
-		return __connman_error_permission_denied(msg);
-
 	str = __connman_notifier_get_state();
 
 	return g_dbus_create_reply(msg, DBUS_TYPE_STRING, &str,
@@ -166,10 +170,6 @@ static DBusMessage *create_profile(DBusConnection *conn,
 	dbus_message_get_args(msg, NULL, DBUS_TYPE_STRING, &name,
 							DBUS_TYPE_INVALID);
 
-	if (__connman_security_check_privilege(msg,
-					CONNMAN_SECURITY_PRIVILEGE_MODIFY) < 0)
-		return __connman_error_permission_denied(msg);
-
 	err = __connman_profile_create(name, &path);
 	if (err < 0)
 		return __connman_error_failed(msg, -err);
@@ -189,10 +189,6 @@ static DBusMessage *remove_profile(DBusConnection *conn,
 	dbus_message_get_args(msg, NULL, DBUS_TYPE_OBJECT_PATH, &path,
 							DBUS_TYPE_INVALID);
 
-	if (__connman_security_check_privilege(msg,
-					CONNMAN_SECURITY_PRIVILEGE_MODIFY) < 0)
-		return __connman_error_permission_denied(msg);
-
 	err = __connman_profile_remove(path);
 	if (err < 0)
 		return __connman_error_failed(msg, -err);
@@ -211,10 +207,6 @@ static DBusMessage *remove_provider(DBusConnection *conn,
 	dbus_message_get_args(msg, NULL, DBUS_TYPE_STRING, &path,
 			      DBUS_TYPE_INVALID);
 
-	if (__connman_security_check_privilege(msg,
-				CONNMAN_SECURITY_PRIVILEGE_MODIFY) < 0)
-		return __connman_error_permission_denied(msg);
-
 	err = __connman_provider_remove(path);
 	if (err < 0)
 		return __connman_error_failed(msg, -err);
@@ -468,10 +460,6 @@ static DBusMessage *connect_service(DBusConnection *conn,
 
 	DBG("conn %p", conn);
 
-	if (__connman_security_check_privilege(msg,
-					CONNMAN_SECURITY_PRIVILEGE_MODIFY) < 0)
-		return __connman_error_permission_denied(msg);
-
 	err = __connman_service_create_and_connect(msg);
 	if (err < 0) {
 		if (err == -EINPROGRESS) {
@@ -493,10 +481,6 @@ static DBusMessage *connect_provider(DBusConnection *conn,
 
 	DBG("conn %p", conn);
 
-	if (__connman_security_check_privilege(msg,
-				CONNMAN_SECURITY_PRIVILEGE_MODIFY) < 0)
-		return __connman_error_permission_denied(msg);
-
 	err = __connman_provider_create_and_connect(msg);
 	if (err < 0) {
 		if (err == -EINPROGRESS) {
@@ -554,7 +538,7 @@ static DBusMessage *register_counter(DBusConnection *conn,
 					DBusMessage *msg, void *data)
 {
 	const char *sender, *path;
-	unsigned int interval;
+	unsigned int accuracy, period;
 	int err;
 
 	DBG("conn %p", conn);
@@ -562,10 +546,13 @@ static DBusMessage *register_counter(DBusConnection *conn,
 	sender = dbus_message_get_sender(msg);
 
 	dbus_message_get_args(msg, NULL, DBUS_TYPE_OBJECT_PATH, &path,
-						DBUS_TYPE_UINT32, &interval,
+						DBUS_TYPE_UINT32, &accuracy,
+						DBUS_TYPE_UINT32, &period,
 							DBUS_TYPE_INVALID);
 
-	err = __connman_counter_register(sender, path, interval);
+	/* FIXME: add handling of accuracy parameter */
+
+	err = __connman_counter_register(sender, path, period);
 	if (err < 0)
 		return __connman_error_failed(msg, -err);
 
@@ -652,7 +639,7 @@ static GDBusMethodTable manager_methods[] = {
 						G_DBUS_METHOD_FLAG_ASYNC },
 	{ "RegisterAgent",     "o",     "",      register_agent     },
 	{ "UnregisterAgent",   "o",     "",      unregister_agent   },
-	{ "RegisterCounter",   "ou",    "",      register_counter   },
+	{ "RegisterCounter",   "ouu",   "",      register_counter   },
 	{ "UnregisterCounter", "o",     "",      unregister_counter },
 	{ "RequestSession",    "s",     "o",     request_session    },
 	{ "ReleaseSession",    "s",     "",      release_session    },
